==> open-xchange-core_7.2.2.orig.tar.bz2: open-xchange-core-7.2.2/com.openexchange.textxtraction/src/com/openexchange/textxtraction/AbstractTextXtractService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.textxtraction;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.nio.charset.Charset;
import org.apache.tika.io.TikaInputStream;
import com.openexchange.exception.OXException;
import com.openexchange.java.Charsets;
import com.openexchange.java.Streams;

/**
 * {@link AbstractTextXtractService} - The abstract {@link TextXtractService} class providing default implementation for
 * {@link #extractFrom(String, String)} and {@link #extractFromResource(String, String)}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public abstract class AbstractTextXtractService implements TextXtractService {

    /**
     * The ISO-8859-1 character set.
     */
    protected static final Charset CHARSET_ISO_8859_1 = Charsets.ISO_8859_1;

    /**
     * Initializes a new {@link AbstractTextXtractService}.
     */
    protected AbstractTextXtractService() {
        super();
    }

    @Override
    public String extractFrom(final String content, final String optMimeType) throws OXException {
        return extractFrom(Streams.newByteArrayInputStream(content.getBytes(CHARSET_ISO_8859_1)), optMimeType);
    }

    @Override
    public String extractFromResource(final String resource, final String optMimeType) throws OXException {
        final File file = new File(resource);
        InputStream input = null;
        try {
            /*
             * Generate an InputStream that supports mark()/reset()
             */
            if (file.isFile()) {
                input = new BufferedInputStream(new FileInputStream(file));
            } else {
                input = TikaInputStream.get(new URL(resource));
            }
            return extractFrom(input, optMimeType);
        } catch (final IOException e) {
            throw TextXtractExceptionCodes.IO_ERROR.create(e, e.getMessage());
        } finally {
            Streams.close(input);
        }
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.textxtraction/src/com/openexchange/textxtraction/AbstractTextXtractService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.textxtraction;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.nio.charset.Charset;
import org.apache.tika.io.TikaInputStream;
import com.openexchange.exception.OXException;
import com.openexchange.java.Charsets;
import com.openexchange.java.Streams;

/**
 * {@link AbstractTextXtractService} - The abstract {@link TextXtractService} class providing default implementation for
 * {@link #extractFrom(String, String)} and {@link #extractFromResource(String, String)}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public abstract class AbstractTextXtractService implements TextXtractService {

    /**
     * The ISO-8859-1 character set.
     */
    protected static final Charset CHARSET_ISO_8859_1 = Charsets.ISO_8859_1;

    /**
     * Initializes a new {@link AbstractTextXtractService}.
     */
    protected AbstractTextXtractService() {
        super();
    }

    @Override
    public String extractFrom(final String content, final String optMimeType) throws OXException {
        return extractFrom(Streams.newByteArrayInputStream(content.getBytes(CHARSET_ISO_8859_1)), optMimeType);
    }

    @Override
    public String extractFromResource(final String resource, final String optMimeType) throws OXException {
        final File file = new File(resource);
        InputStream input = null;
        try {
            /*
             * Generate an InputStream that supports mark()/reset()
             */
            if (file.isFile()) {
                input = Streams.bufferedInputStreamFor(new FileInputStream(file));
            } else {
                input = TikaInputStream.get(new URL(resource));
            }
            return extractFrom(input, optMimeType);
        } catch (final IOException e) {
            throw TextXtractExceptionCodes.IO_ERROR.create(e, e.getMessage());
        } finally {
            Streams.close(input);
        }
    }

}
